@@ -1,7 +1,7 @@
 package Perinci::Object::Function;
 
-our $DATE = '2016-11-21'; # DATE
-our $VERSION = '0.25'; # VERSION
+our $DATE = '2016-12-15'; # DATE
+our $VERSION = '0.26'; # VERSION
 
 use 5.010;
 use strict;
@@ -40,6 +40,12 @@ sub can_dry_run {
     $ff->{dry_run} // $ff->{tx} && $ff->{tx}{v} == 2;
 }
 
+sub default_dry_run {
+    my $self = shift;
+    my $ff = ${$self}->{features} // {};
+    ref($ff->{dry_run}) eq 'HASH' && $ff->{dry_run}{default};
+}
+
 # convenience for accessing args property
 sub arg {
     my $self = shift;
@@ -71,7 +77,7 @@ Perinci::Object::Function - Represent function metadata
 
 =head1 VERSION
 
-This document describes version 0.25 of Perinci::Object::Function (from Perl distribution Perinci-Object), released on 2016-11-21.
+This document describes version 0.26 of Perinci::Object::Function (from Perl distribution Perinci-Object), released on 2016-12-15.
 
 =head1 SYNOPSIS
 
@@ -116,6 +122,12 @@ Check whether function can do dry run, either from the C<dry_run> feature, or
 from the C<tx> feature. (Transaction can be used to emulate dry run, by calling
 the function with C<< -tx_action => 'check_state' >> only.)
 
+=head2 $risub->default_dry_run => BOOL
+
+Starting from Rinci 1.1.83, the C<dry_run> feature property can be a hash
+instead of a bool, and can contain this pair C<< default=>1 >> to specify that
+dry-run mode should be the default operation (e.g. for safety).
+
 =head2 $risub->arg(NAME[, VALUE])
 
 Get or set argument (B<args> property in metadata). If an argument doesn't
@@ -127,7 +139,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Ob
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Object>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Object>.
 
 =head1 BUGS
 
